/**
 * Evaluates if the specified type is `any`.
 * @example
 * type A = isAny<any>;
 * //   ^? true
 * type B = isAny<string>;
 * //   ^? false
 * type C = isAny<number | any>;
 * //   ^? true
 */
export type isAny<T> = 0 extends (1 & T) ? true : false;
/**
 * A utility type that substitutes a default type when the provided type is `any`.
 * @example
 * type A = defaultOnAny<any, string>;  // Result: string
 * type B = defaultOnAny<number, string>;  // Result: number
 */
export type defaultOnAny<Type, Default> = isAny<Type> extends true ? Default : Type;
