"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RTFT_CONFIG = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const typescript_1 = __importDefault(require("typescript"));
const getClientConfigFile = () => {
    const clientConfigPath = path_1.default.join(process.cwd(), 'rt.config.ts');
    if (!fs_1.default.existsSync(clientConfigPath)) {
        console.info('Not config file found (rt.config.ts).\n');
        return {};
    }
    try {
        const buffer = fs_1.default.readFileSync(clientConfigPath);
        const compiled = typescript_1.default.transpile(buffer.toString());
        const evalConfig = eval(compiled);
        return evalConfig || {};
    }
    catch (e) {
        console.error('Error evaluating client config:', e);
        return {};
    }
};
const getConfig = () => {
    const lastArgv = process.argv.slice(2).at(-1);
    const pathToTest = lastArgv && !lastArgv.startsWith('-') ? lastArgv.replaceAll('\\', '/') : null;
    const config = {
        verbose: !!pathToTest || process.argv.includes('--verbose'),
        include: ['.*(\.(spec|test)(-types)?\.ts)$'],
        exclude: ['.*node_modules.*'],
    };
    const clientConfig = getClientConfigFile();
    const includeByConsole = process.argv.find((arg) => arg.includes('--include='))?.split('=')[1];
    if (pathToTest) {
        config.include = [pathToTest];
    }
    else if (includeByConsole) {
        config.include = [includeByConsole];
    }
    else if (clientConfig?.testing?.include) {
        config.include = clientConfig?.testing?.include;
    }
    const excludeByConsole = process.argv.find((arg) => arg.includes('--exclude='))?.split('=')[1];
    if (excludeByConsole) {
        config.exclude = [excludeByConsole];
    }
    else if (clientConfig?.testing?.exclude) {
        config.exclude = clientConfig?.testing?.exclude;
    }
    return config;
};
const preProccesedConfig = getConfig();
exports.RTFT_CONFIG = {
    ...preProccesedConfig,
    include: preProccesedConfig.include.map((pattern) => RegExp(pattern)),
    exclude: preProccesedConfig.exclude.map((pattern) => RegExp(pattern)),
};
